#
# spec file for package python-validate-pyproject
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-validate-pyproject
Version:        0.15
Release:        1.6
Summary:        Validation library and CLI tool for checking on 'pyprojecttoml'
License:        BSD-3-Clause AND MIT AND MPL-2.0
URL:            https://github.com/abravalheri/validate-pyproject/
Source:         https://files.pythonhosted.org/packages/source/v/validate-pyproject/validate-pyproject-%{version}.tar.gz
BuildRequires:  %{python_module fastjsonschema}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if 0%{python_version_nodots} < 38
Requires:       python-importlib-metadata
%endif
%if 0%{python_version_nodots} < 37
Requires:       python-importlib-resources
%endif
Requires:       python-fastjsonschema
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-validate_pyproject = %{version}-%{release}
# SECTION test
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module importlib-metadata if %python-base < 3.8}
BuildRequires:  %{python_module importlib-resources if %python-base < 3.7}
BuildRequires:  %{python_module packaging >= 20.4}
BuildRequires:  %{python_module tomli >= 1.2.1 if %python-base < 3.11}
BuildRequires:  %{python_module trove-classifiers >= 2021.10.20}
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
Validation library and CLI tool for checking on 'pyproject.toml' files using JSON Schema

%prep
%setup -q -n validate-pyproject-%{version}
sed -i '/--cov/d' setup.cfg

%build
# have to use PEP517: gh#abravalheri/validate-pyproject#52
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/validate-pyproject
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Ignore test_pre_compile that fails because how fastjsonschema and
# validate-pyproject packages are installed
%pytest --ignore tests/test_pre_compile.py --ignore tests/test_vendoring.py -k "not downloaded"

%post
%python_install_alternative validate-pyproject

%postun
%python_uninstall_alternative validate-pyproject

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/validate-pyproject
%{python_sitelib}/validate_pyproject
%{python_sitelib}/validate_pyproject-%{version}*-info

%changelog
* Fri Dec 15 2023 Dirk Müller <dmueller@suse.com>
- update to 0.15:
  * Update ``setuptools`` schema definitions, #112
  * Add ``__repr__`` to plugin wrapper
  * Fix standard ``$schema`` ending ``#``
  * Ensure reporting show more detailed error messages for
    ``RedefiningStaticFieldAsDynamic``
  * Add support for ``repo-review``
* Tue May 30 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.13:
  * Make it clear when using input from ``stdin``, #96
  * Fix summary for ``allOf``, #100
  * ``setuptools`` plugin:
  * Improve validation of ``attr`` directives, #101
* Fri May 12 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.12.2:
  * setuptools plugin:
  * Fix problem with license-files patterns, by removing default value.
- 0.12.1:
  * setuptools plugin:
  * Allow PEP 561 stub names in tool.setuptools.package-dir, #87
- 0.12.0:
  * setuptools plugin:
  * Allow PEP 561 stub names in tool.setuptools.packages, #86
- 0.11.0:
  * Improve error message for invalid replacements in the pre_compile CLI, #71
  * Allow package to be build from git archive, #53
  * Improve error message for invalid replacements in the pre_compile CLI, #71
  * Error-out when extra keys are added to project.authors/maintainers, #82
  * De-vendor fastjsonschema, #83
- 0.10.1:
  * Ensure LICENSE.txt is added to wheel.
- 0.10.0:
  * Add NOTICE.txt to license_files, #58
  * Use default SSL context when downloading classifiers from PyPI, #57
  * Remove setup.py, #52
  * Explicitly limit oldest supported Python version
  * Replace usage of cgi.parse_header with email.message.Message
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Apr 18 2023 Matej Cepl <mcepl@suse.com>
- Switch to single spec version build for PSP
* Wed Jul 13 2022 Ben Greiner <code@bnavigator.de>
- initial specfile for v0.9, required by ini2toml
